@@ -8,4 +8,4 @@ pyiwd: A graphical frontend for iwd, Intel's iNet Wireless Daemon.
 #from iwdgui import passwd_entry, pyiwd
 
 #$__all__ = ["pyiwd", "passwd_entry"]
-__all__ = ["pyiwd", "passwd_entry"]
+#__all__ = ["pyiwd", "passwd_entry"]
